"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var immutable_1 = require("immutable");
var actions_1 = require("./actions");
var api_1 = require("./api");
var changesEventSource = null;
var Connector = /** @class */ (function () {
    function Connector(config, dispatch, pathname) {
        this.api = api_1.default;
        this.currentLocation = pathname || '/';
        this.config = config;
        this.dispatch = dispatch;
        this.__listenOnTranslationServer();
        this.translationStore = immutable_1.Map();
        this.previousTranslationsSend = this.translationStore;
        this.sendTimeout = null;
    }
    Connector.prototype.updateLocation = function (location) {
        this.currentLocation = location;
        this.__enqueeSendTranslations();
    };
    Connector.prototype.rememberUsedTranslation = function (locale, path, message) {
        var _this = this;
        this.locale = locale;
        if (!this.config.sync) {
            return;
        }
        if (this.__dataType(message) === 'array') {
            (message || {}).map(function (v, k) { return _this.rememberUsedTranslation(locale, [].concat(path, [k]), v); });
        }
        else {
            this.__rememberTranslation([locale].concat(path), message);
        }
        this.__enqueeSendTranslations();
    };
    Connector.prototype.sendTranslations = function () {
        var _this = this;
        if (!this.config.sync || !this.config.apiUrl || !this.config.apiToken) {
            return;
        }
        if (this.translationStore === this.previousTranslationsSend) {
            return;
        }
        this.translationStore.reduce(function (output, translations, location) { return (output.set(location, translations.filter(function (_, key) { return !_this.previousTranslationsSend.getIn([location, key]); }))); }, immutable_1.Map())
            .filter(function (translations) { return !translations.isEmpty(); })
            .map(function (translations, location) {
            return _this.api(_this.config, 'POST', _this.config.apiEndpoint, {
                location: location,
                locale: _this.locale,
                translations: translations.toIndexedSeq().toJS(),
            });
        });
        this.previousTranslationsSend = this.translationStore;
    };
    Connector.prototype.__enqueeSendTranslations = function () {
        if (!this.config.sync) {
            return;
        }
        if (this.sendTimeout) {
            clearTimeout(this.sendTimeout);
            this.sendTimeout = null;
        }
        this.sendTimeout = setTimeout(this.sendTranslations.bind(this), 1000);
    };
    Connector.prototype.__rememberTranslation = function (keyPath, message) {
        var path = keyPath.join('.');
        this.translationStore = this.translationStore.mergeIn([this.currentLocation, path], {
            data_type: this.__dataType(message),
            key: path,
            text: message,
        });
    };
    Connector.prototype.__listenOnTranslationServer = function () {
        var _this = this;
        var _a = this.config, apiUrl = _a.apiUrl, apiToken = _a.apiToken, sync = _a.sync;
        if (typeof window !== 'undefined' && !changesEventSource && sync) {
            actions_1.fetchTranslations(this.config)(this.dispatch);
            if (this.config.liveSync) {
                var EventSource_1 = require('eventsource');
                changesEventSource = new EventSource_1(api_1.apiUrlResolve("" + apiUrl, "api/v1/changes?token=" + apiToken));
                changesEventSource.addEventListener('translations_changed', function (_a) {
                    var data = _a.data;
                    _this.dispatch(actions_1.updateMessages(JSON.parse(data)));
                });
            }
        }
    };
    Connector.prototype.__dataType = function (value) {
        if (!value && ("" + value).length === 0) {
            return null;
        }
        switch (typeof value) {
            case 'boolean': return 'bool';
            case 'object': return 'array';
            case 'string': return 'string';
            case 'number': return 'float';
            default: return null;
        }
    };
    return Connector;
}());
exports.default = Connector;
//# sourceMappingURL=Connector.js.map