"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var immutable_1 = require("immutable");
var structuredJSON_1 = require("../structuredJSON");
var flatMap = immutable_1.fromJS({
    'en.views.homepage.title': 'Welcome',
});
var structuredMap = {
    en: {
        views: {
            homepage: {
                title: 'Welcome',
            },
        },
    },
};
var structuredImmutableMap = immutable_1.fromJS({
    en: {
        views: {
            homepage: {
                title: 'Welcome',
            },
        },
    },
});
var hybrid = immutable_1.fromJS({
    en: {
        'views.homepage.title': 'Welcome',
    },
    es: {
        'views.homepage.title': 'Bueno',
    },
});
var structured = immutable_1.fromJS({
    en: {
        views: {
            homepage: {
                title: 'Welcome',
            },
        },
    },
    es: {
        views: {
            homepage: {
                title: 'Bueno',
            },
        },
    },
});
describe('creating structed JSON objects', function () {
    it('should create structed object from complete flatmap', function () {
        expect(structuredJSON_1.createStructuredJSON(flatMap)).toEqual(structuredImmutableMap);
    });
    it('should create structed object from hybrid JSON', function () {
        expect(structuredJSON_1.createStructuredJSON(hybrid)).toEqual(structured);
    });
    it('should not change already structured object', function () {
        expect(structuredJSON_1.createStructuredJSON(structured)).toEqual(structured);
    });
});
describe('structureObject', function () {
    it('should construct objects from array of keys', function () {
        expect(structuredJSON_1.__structureObject(['en', 'views', 'homepage', 'title'], 'Welcome')).toEqual(structuredMap);
    });
    it('should return empty object for empty array of keys', function () {
        expect(structuredJSON_1.__structureObject([], 'foo')).toEqual({});
    });
});
describe('isSplittableKey', function () {
    it('should say "en.views.homepage" is splittable key', function () {
        expect(structuredJSON_1.__isSplittableKey('en.views.homepage')).toBe(true);
    });
    it('should say "Lorem ipsum. Dolor sit amet." is not splittable key', function () {
        expect(structuredJSON_1.__isSplittableKey('Lorem ipsum. Dolor sit amet.')).toBe(false);
    });
    it('should say "Fin." is not splittable key', function () {
        expect(structuredJSON_1.__isSplittableKey('Fin.')).toBe(false);
    });
});
//# sourceMappingURL=structuredJSON.spec.js.map