"use strict";
/* tslint:disable max-classes-per-file */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var immutable_1 = require("immutable");
var React = require("react");
var TestUtils = require("react-dom/test-utils");
var react_redux_1 = require("react-redux");
var redux_1 = require("redux");
var actions_1 = require("../actions");
var Provider_1 = require("../Provider");
var reducer_1 = require("../reducer");
var translate_1 = require("../translate");
var initial = {
    messages: immutable_1.fromJS({
        cs: { home: { description: 'Foo', fallback: 'Fallback' } },
        en: { home: { header: { title: 'FooBar' }, description: 'enFoo', about: 'Bar' } },
    }),
    locale: 'cs',
    fallbackLocale: 'en',
};
var counter = function (state, action) {
    if (state === void 0) { state = 0; }
    return action.type === 'INC' ? state + 1 : state;
};
var store = redux_1.createStore(redux_1.combineReducers({ translate: reducer_1.default, counter: counter }), { translate: initial, counter: 2 });
describe('Translate Decorator', function () {
    var Passthrough = /** @class */ (function (_super) {
        __extends(Passthrough, _super);
        function Passthrough() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        Passthrough.prototype.render = function () {
            return React.createElement("div", null);
        };
        return Passthrough;
    }(React.Component));
    var Container = /** @class */ (function (_super) {
        __extends(Container, _super);
        function Container() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        Container.prototype.render = function () {
            return (React.createElement(Passthrough, __assign({}, this.props)));
        };
        return Container;
    }(React.Component));
    var createStub = function (scope, options) {
        if (options === void 0) { options = {}; }
        var DecoratedContainer = translate_1.translate(scope, options)(Container);
        var container = TestUtils.renderIntoDocument(React.createElement(react_redux_1.Provider, { store: store },
            React.createElement(Provider_1.default, null,
                React.createElement(DecoratedContainer, null))));
        return TestUtils.findRenderedComponentWithType(container, Passthrough);
    };
    it('should have a msg prop', function () {
        expect(createStub().props.msg('description', { scope: 'home' }).toString()).toEqual('Foo');
    });
    it('should have default message', function () {
        expect(createStub().props.msg('Default Message', { scope: 'home' }).toString()).toEqual('Default Message');
    });
    it('should have a hasMsg prop', function () {
        expect(createStub().props.hasMsg('description', { scope: 'home' })).toEqual(true);
    });
    it('should have a hasMsg message and return false for default text', function () {
        expect(createStub().props.hasMsg('Default Message', { scope: 'home' })).toEqual(false);
    });
    it('should return undefined when disableDefault', function () {
        expect(createStub('', { disableDefault: true }).props.msg('Default Message', { scope: 'home' }).toString()).toEqual(undefined);
    });
    it('should have a msg prop with scope', function () {
        expect(createStub('home').props.msg('description').toString()).toEqual('Foo');
    });
    it('should have a msg prop with array scope', function () {
        expect(createStub(['home', 'header']).props.msg('title').toString()).toEqual('FooBar');
    });
    it('should have a msg prop with dotted scope', function () {
        expect(createStub('home.header').props.msg('title').toString()).toEqual('FooBar');
    });
    describe('shouldComponentUpdate', function () {
        var DecoratedContainer = translate_1.translate()(Passthrough);
        var getSpy = function () {
            var container = TestUtils.renderIntoDocument(React.createElement(react_redux_1.Provider, { store: store },
                React.createElement(Provider_1.default, null,
                    React.createElement(DecoratedContainer, null))));
            var instance = TestUtils.findRenderedComponentWithType(container, DecoratedContainer);
            var spy = jest.fn(instance.render);
            instance.render = spy;
            return spy;
        };
        it('should rerender on locale change', function () {
            var spy = getSpy();
            store.dispatch(actions_1.changeLocale('en'));
            store.dispatch(actions_1.changeLocale('en'));
            store.dispatch(actions_1.changeLocale('cs'));
            store.dispatch(actions_1.changeLocale('cs'));
            store.dispatch(actions_1.changeLocale('en'));
            store.dispatch(actions_1.changeLocale('en'));
            expect(spy.mock.calls.length).toEqual(3);
        });
        it('should rerender on message change', function () {
            var spy = getSpy();
            store.dispatch(actions_1.updateMessages(immutable_1.fromJS({ en: { foo: 'bar' } })));
            store.dispatch(actions_1.updateMessages(immutable_1.fromJS({ en: { foo: 'bar' } })));
            store.dispatch(actions_1.updateMessages(immutable_1.fromJS({ en: { foo: 'bar2' } })));
            store.dispatch(actions_1.updateMessages(immutable_1.fromJS({ en: { foo: 'bar2' } })));
            expect(spy.mock.calls.length).toEqual(2);
            store.dispatch({ type: 'INC' });
            store.dispatch({ type: 'INC' });
            store.dispatch({ type: 'INC' });
            expect(spy.mock.calls.length).toEqual(2);
        });
    });
});
//# sourceMappingURL=translate.spec.js.map