"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var immutable_1 = require("immutable");
var radium_1 = require("radium");
var React = require("react");
var actions_1 = require("../actions");
var Translation_1 = require("./Translation");
function convertDotPath(path, value) {
    var _a;
    var _b = path.split('.').reverse(), last = _b[0], paths = _b.slice(1);
    return paths.reduce(function (acc, el) {
        var _a;
        return (_a = {}, _a[el] = acc, _a);
    }, (_a = {}, _a[last] = value, _a));
}
var emptyMap = immutable_1.Map();
var Editor = /** @class */ (function (_super) {
    __extends(Editor, _super);
    function Editor() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = {
            pendingChanges: immutable_1.Map(),
            sortedKeys: _this.sortAndFilterKeys(_this.props.search),
        };
        _this.onChange = function (keyPath, originalText) { return function (_a) {
            var value = _a.target.value;
            var dispatch = _this.props.dispatch;
            var pendingChanges = _this.state.pendingChanges;
            if (!pendingChanges.has(keyPath)) { // new update
                _this.setState({ pendingChanges: pendingChanges.set(keyPath, originalText) });
            }
            else if (pendingChanges.get(keyPath) === value) { // reset
                _this.setState({ pendingChanges: pendingChanges.remove(keyPath) });
            }
            dispatch(actions_1.updateMessages(convertDotPath(keyPath, value)));
        }; };
        _this.updateTranslation = function (key, text, keyPath) {
            var updateTranslation = _this.props.updateTranslation;
            var pendingChanges = _this.state.pendingChanges;
            if (pendingChanges.has(keyPath)) {
                _this.setState({ pendingChanges: pendingChanges.remove(keyPath) });
            }
            updateTranslation(key, text);
        };
        _this.renderTranslation = function (data) {
            var _a = _this.props, search = _a.search, messages = _a.messages;
            var pendingChanges = _this.state.pendingChanges;
            if (!data) {
                return null;
            }
            var text = messages.getIn(("" + data.get('key')).split('.'));
            if (immutable_1.Map.isMap(text)) {
                return React.createElement("div", { key: "" + data.get('key') });
            }
            return (React.createElement(Translation_1.default, { key: "" + data.get('key'), dataType: "" + data.get('data_type'), keyPath: "" + data.get('key'), text: text || data.get('text'), opened: search.length > 0, onChange: _this.onChange, pendingChanges: pendingChanges, updateTranslation: _this.updateTranslation }));
        };
        return _this;
    }
    Editor.prototype.componentWillReceiveProps = function (next) {
        var _a = this.props, translationStore = _a.translationStore, pathname = _a.pathname, search = _a.search;
        var anyNewTranslation = (translationStore.get(pathname) || emptyMap).keySeq().hashCode() !== (next.translationStore.get(pathname) || emptyMap).keySeq().hashCode();
        if (pathname !== next.pathname || search !== next.search || anyNewTranslation) {
            this.setState({ sortedKeys: this.sortAndFilterKeys(next.search) });
        }
    };
    Editor.prototype.sortAndFilterKeys = function (search) {
        var _a = this.props, translationStore = _a.translationStore, locale = _a.locale, pathname = _a.pathname;
        var searchPattern = search.length > 0
            ? new RegExp(search.split(' ').join('.*'), 'i')
            : null;
        var keys = (translationStore.get(pathname) || emptyMap);
        var localeKeys = keys.filter(function (d) { return ("" + d.get('key')).startsWith(locale); });
        var filteredKeys = searchPattern
            ? localeKeys.filter(function (d) { return searchPattern.test([d.get('key'), d.get('text')].join()); })
            : localeKeys;
        return filteredKeys.sortBy(function (k) { return k.get('key'); });
    };
    Editor.prototype.render = function () {
        var sortedKeys = this.state.sortedKeys;
        return (React.createElement("div", null,
            React.createElement("div", { style: { width: 'auto', height: 'auto' } }, sortedKeys.map(this.renderTranslation))));
    };
    return Editor;
}(React.PureComponent));
exports.Editor = Editor;
exports.default = radium_1.default(Editor);
//# sourceMappingURL=Editor.js.map