import { Map } from 'immutable';
import * as PropTypes from 'prop-types';
import * as React from 'react';
import { StoredTranslation, StoredTranslations } from '../Connector';
import { Translator } from '../translator';
import { AppStore, Messages, TranslationResult } from '../types';
import { UserProps } from './User';
export declare type ApiCall = (method: 'put' | 'post' | 'delete' | 'get', endpoint: string, data?: any) => Promise<any>;
export declare type SetUser = (user?: UserProps) => void;
export declare type SetError = (error?: string) => void;
export declare type UpdateTranslation = (key: string, text: string, keyPath?: string) => void;
export interface TranslationEditorProps {
    history?: any;
    pathname?: string;
}
export interface TranslationEditorContext {
    translator: Translator;
    store: AppStore;
}
export interface TranslationEditorState {
    error?: string;
    opened: boolean;
    search: string;
    historyUnsubscribe: () => void;
    locale: string;
    messages: Messages;
    pathname: string;
    user: UserProps;
    translationStore: StoredTranslations;
    translatorSubscription: () => void;
    unsubscribeStore: () => void;
}
export declare class TranslationEditor extends React.PureComponent<TranslationEditorProps, TranslationEditorState> {
    context: TranslationEditorContext;
    static contextTypes: {
        translator: PropTypes.Requireable<any>;
        store: PropTypes.Requireable<any>;
    };
    state: {
        error: undefined;
        opened: boolean;
        search: string;
        historyUnsubscribe: () => void;
        messages: Map<string, string | number | boolean | object | Map<string, TranslationResult> | undefined>;
        pathname: string;
        locale: string;
        user: {
            username: undefined;
        };
        translationStore: Map<string, Map<string, StoredTranslation>>;
        translatorSubscription: () => void;
        unsubscribeStore: () => void;
    };
    componentWillMount(): void;
    componentWillReceiveProps(next: TranslationEditorProps): void;
    componentWillUnmount(): void;
    onChange: (keyPath: string) => (event: React.ChangeEvent<HTMLTextAreaElement>) => void;
    setUser: SetUser;
    setError: SetError;
    togglOpen: () => void;
    updateSearch: (search: string) => void;
    loginOnMount: () => void;
    apiCall: ApiCall;
    updateState: (newPathname?: string | undefined) => void;
    updateTranslation: UpdateTranslation;
    render(): JSX.Element;
}
export declare const style: {
    label: React.CSSProperties;
    input: {
        border: string;
        height: string;
        lineheight: string;
        padding: string;
        marginBottom: string;
        width: string;
    };
    button: React.CSSProperties;
    wrapper: {
        position: string;
    };
    container: {
        position: string;
        transition: string;
        marginRight: number;
    };
    containerMoved: {
        marginRight: number;
    };
    panel: {
        background: string;
        position: string;
        right: number;
        top: number;
        bottom: number;
        zIndex: number;
        overflow: string;
        width: number;
        transition: string;
    };
    panelOpened: {
        borderLeft: string;
        right: number;
        padding: string;
    };
    navigation: {
        position: string;
        top: string;
        right: string;
        maxWidth: string;
    };
};
declare const _default: typeof TranslationEditor;
export default _default;
