"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var immutable_1 = require("immutable");
var fetch = require("isomorphic-fetch");
var PropTypes = require("prop-types");
var radium_1 = require("radium");
var React = require("react");
var actions_1 = require("../actions");
var Editor_1 = require("./Editor");
var Opener_1 = require("./Opener");
var Panel_1 = require("./Panel");
var Search_1 = require("./Search");
var SignIn_1 = require("./SignIn");
var SignOut_1 = require("./SignOut");
var User_1 = require("./User");
function convertDotPath(path, value) {
    var _a;
    var _b = path.split('.').reverse(), last = _b[0], paths = _b.slice(1);
    return paths.reduce(function (acc, el) {
        var _a;
        return (_a = {}, _a[el] = acc, _a);
    }, (_a = {}, _a[last] = value, _a));
}
var TranslationEditor = /** @class */ (function (_super) {
    __extends(TranslationEditor, _super);
    function TranslationEditor() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = {
            error: undefined,
            opened: false,
            search: '',
            historyUnsubscribe: function () { },
            messages: immutable_1.Map(),
            pathname: '/',
            locale: 'en',
            user: { username: undefined },
            translationStore: immutable_1.Map(),
            translatorSubscription: function () { },
            unsubscribeStore: function () { },
        };
        _this.onChange = function (keyPath) { return function (event) {
            var dispatch = _this.context.store.dispatch;
            dispatch(actions_1.updateMessages(convertDotPath(keyPath, event.target.value)));
        }; };
        _this.setUser = function (user) { return _this.setState({ user: user || { username: undefined } }); };
        _this.setError = function (error) { return _this.setState({ error: error }); };
        _this.togglOpen = function () { return _this.setState({ opened: !_this.state.opened }); };
        _this.updateSearch = function (search) { return _this.setState({ search: search }); };
        _this.loginOnMount = function () {
            _this.apiCall('get', '/api_frontend/v1/me').then(function (data) {
                if (!data.error) {
                    _this.setUser(data.user);
                }
            });
        };
        _this.apiCall = function (method, endpoint, data) {
            if (data === void 0) { data = {}; }
            var connector = _this.context.translator.connector;
            if (!connector) {
                return Promise.resolve({});
            }
            var apiUrl = connector.config.apiUrl;
            var url = [apiUrl, endpoint].join('/').replace(/(\w)\/+/g, '$1/');
            _this.setError();
            return fetch(url, {
                method: method,
                body: method === 'get' ? null : JSON.stringify(data),
                credentials: 'include',
                headers: {
                    'Content-type': 'application/json',
                },
            }).then(function (d) { return d.json(); }).catch(function (error) { return _this.setError(JSON.stringify(error)); });
        };
        _this.updateState = function (newPathname) {
            _this.setState({
                messages: _this.context.store.getState().translate.messages,
            });
            setTimeout(function () {
                var pathname = newPathname || window.location.pathname;
                var pathChanged = (_this.state.pathname !== pathname);
                var search = pathChanged ? '' : _this.state.search;
                var error = pathChanged ? '' : _this.state.error;
                _this.setState({
                    translationStore: _this.context.translator.connector && _this.context.translator.connector.translationStore,
                    locale: _this.context.translator.__locale(),
                    pathname: pathname,
                    search: search,
                    error: error,
                });
            }, 100);
        };
        _this.updateTranslation = function (key, text) {
            var _a = _this.context, getState = _a.store.getState, connector = _a.translator.connector;
            if (!connector) {
                return Promise.resolve({});
            }
            var apiToken = connector.config.apiToken;
            return _this.apiCall('put', '/api_frontend/v1/translations/update_by_key', {
                api_token: apiToken,
                locale: getState().translate.locale,
                key: key,
                translation: {
                    text: text,
                },
            }).then(function (data) {
                if (data.error) {
                    _this.setError(data.error);
                }
                return data;
            });
        };
        return _this;
    }
    TranslationEditor.prototype.componentWillMount = function () {
        var _a = this.context, store = _a.store, translator = _a.translator;
        var historyUnsubscribe = this.props.history ? this.props.history.listen(this.updateState) : undefined;
        if (!store) {
            return;
        }
        this.setState({
            unsubscribeStore: store.subscribe(this.updateState),
            translatorSubscription: translator.subscribeMsgClick(this.updateSearch),
            historyUnsubscribe: historyUnsubscribe,
        });
        this.updateState();
        this.loginOnMount();
    };
    TranslationEditor.prototype.componentWillReceiveProps = function (next) {
        if (next.pathname !== this.props.pathname) {
            this.updateState(next.pathname);
        }
    };
    TranslationEditor.prototype.componentWillUnmount = function () {
        var _a = this.state, historyUnsubscribe = _a.historyUnsubscribe, unsubscribeStore = _a.unsubscribeStore, translatorSubscription = _a.translatorSubscription;
        unsubscribeStore();
        historyUnsubscribe();
        translatorSubscription();
    };
    TranslationEditor.prototype.render = function () {
        var _this = this;
        var _a = this.state, translationStore = _a.translationStore, opened = _a.opened, locale = _a.locale, pathname = _a.pathname, search = _a.search, user = _a.user, error = _a.error;
        var children = this.props.children;
        var _b = this.context.store, getState = _b.getState, dispatch = _b.dispatch;
        return (React.createElement("div", { style: exports.style.wrapper },
            React.createElement(Opener_1.default, { open: this.togglOpen, width: PANEL_WIDTH, opened: opened }),
            React.createElement("div", { style: [exports.style.container, opened && exports.style.containerMoved] }, children),
            React.createElement("div", { style: [exports.style.panel, opened && exports.style.panelOpened] },
                opened && !user.username &&
                    React.createElement(SignIn_1.default, { error: error, apiCall: this.apiCall, setUser: this.setUser, setError: this.setError }),
                opened && user.username &&
                    React.createElement(Panel_1.default, { error: error },
                        React.createElement("div", { style: exports.style.navigation },
                            React.createElement(User_1.default, __assign({}, user)),
                            React.createElement(SignOut_1.default, { apiCall: this.apiCall, setUser: this.setUser })),
                        React.createElement(Search_1.default, { search: search, onChange: function (search) { return _this.setState({ search: search }); } }),
                        React.createElement(Editor_1.default, { dispatch: dispatch, messages: getState().translate.messages, locale: locale, pathname: pathname, search: search, translationStore: translationStore, updateTranslation: this.updateTranslation }),
                        React.createElement(radium_1.default.Style, { rules: {
                                '.cnt': {
                                    position: 'relative',
                                },
                                '.cnt:hover:after': {
                                    opacity: 1,
                                    transition: '0.5s all',
                                },
                                '.cnt:after': {
                                    content: 'attr(data-key)',
                                    background: 'black',
                                    color: 'white',
                                    position: 'absolute',
                                    padding: '3px 5px',
                                    fontSize: '12px',
                                    letterSpacing: 'normal',
                                    fontWeight: '400 !important',
                                    left: 0,
                                    bottom: '100%',
                                    opacity: 0,
                                },
                            } })))));
    };
    TranslationEditor.contextTypes = {
        translator: PropTypes.object,
        store: PropTypes.object,
    };
    return TranslationEditor;
}(React.PureComponent));
exports.TranslationEditor = TranslationEditor;
var PANEL_WIDTH = 450;
exports.style = {
    label: {
        fontSize: '12px',
        display: 'block',
        fontWeight: 600,
        marginBottom: '3px',
    },
    input: {
        border: "1px solid #555",
        height: '34px',
        lineheight: '34px',
        padding: '5px',
        marginBottom: '15px',
        width: '100%',
    },
    button: {
        backgroundColor: '#111111',
        color: 'white',
        border: '1px solid #111111',
        fontWeight: 600,
        fontSize: '14px',
        padding: '6px 14px',
        transition: 'all .2s',
        ':hover': {
            cursor: 'pointer',
            backgroundColor: '#000000',
        },
    },
    wrapper: {
        position: 'relative',
    },
    container: {
        position: 'relative',
        transition: 'all .2s',
        marginRight: 0,
    },
    containerMoved: {
        marginRight: PANEL_WIDTH,
    },
    panel: {
        background: 'white',
        position: 'fixed',
        right: -PANEL_WIDTH,
        top: 0,
        bottom: 0,
        zIndex: 11,
        overflow: 'auto',
        width: PANEL_WIDTH,
        transition: 'all .2s',
    },
    panelOpened: {
        borderLeft: '3px solid #111111',
        right: 0,
        padding: '15px',
    },
    navigation: {
        position: 'absolute',
        top: '20px',
        right: '15px',
        maxWidth: '235px',
    },
};
exports.default = radium_1.default(TranslationEditor);
//# sourceMappingURL=TranslationEditor.js.map