"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var moment = require("moment");
exports.defaultDateFormat = 'D.M.YYYY';
exports.defaultOptions = {
    precision: 10,
    delimiter: ',',
    format: exports.defaultDateFormat,
    separator: '.',
    template: '%n %u',
    unit: '',
    trimTrailingZeros: true,
};
function mergeOptionsWithDefault(givenOptions) {
    return __assign({}, exports.defaultOptions, givenOptions);
}
exports.mergeOptionsWithDefault = mergeOptionsWithDefault;
function formatDate(givenDate, locale, format) {
    var date = moment(givenDate);
    date.locale(locale);
    return date.format(format || exports.defaultDateFormat);
}
exports.formatDate = formatDate;
function formatNumber(input, givenOptions) {
    if (givenOptions === void 0) { givenOptions = {}; }
    var options = mergeOptionsWithDefault(givenOptions);
    var rounedNumber = roundNumber(input, options);
    var formattedNumber = formatNumberSeparatorAndDelimiter(rounedNumber, options);
    if (formattedNumber === 'NaN') {
        return '';
    }
    return options.template
        .replace('%n', formattedNumber)
        .replace('%u', options.unit)
        .trim();
}
exports.formatNumber = formatNumber;
function formatCurrency(input, givenOptions) {
    if (givenOptions === void 0) { givenOptions = {}; }
    return formatNumber(input, __assign({ trimTrailingZeros: false }, givenOptions));
}
exports.formatCurrency = formatCurrency;
function formatNumberSeparatorAndDelimiter(input, givenOptions) {
    if (givenOptions === void 0) { givenOptions = {}; }
    var options = mergeOptionsWithDefault(givenOptions);
    var numbers = input.toFixed(givenOptions.precision).toString().split('.');
    numbers[0] = numbers[0].replace(/\B(?=(\d{3})+(?!\d))/g, options.delimiter);
    if (numbers[1] && givenOptions.trimTrailingZeros) {
        numbers[1] = numbers[1].replace(/0+$/g, '');
        if (numbers[1] === '') {
            numbers.splice(1, 1);
        }
    }
    return numbers.join(options.separator);
}
exports.formatNumberSeparatorAndDelimiter = formatNumberSeparatorAndDelimiter;
function roundNumber(input, givenOptions) {
    var options = mergeOptionsWithDefault(givenOptions);
    var decimal = Math.pow(10, options.precision);
    return Math.round(input * decimal) / decimal;
}
exports.roundNumber = roundNumber;
//# sourceMappingURL=format.js.map