"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var immutable_1 = require("immutable");
function __isSplittableKey(key) {
    return key.includes('.') && !key.includes(' ') && key.lastIndexOf('.') !== key.length - 1;
}
exports.__isSplittableKey = __isSplittableKey;
function createStructuredJSON(messages) {
    var result = immutable_1.Map();
    if (messages && typeof messages === 'object') { // we only want to incluence objects
        messages.forEach(function (value, key) {
            if (key) {
                if (__isSplittableKey(key)) { // can we broke it into smaller objects?
                    result = result.mergeDeep(__structureObject(key.split('.'), value));
                }
                else { // if not, let's test the value - it may contain some splittable keys
                    result = result.set(key, createStructuredJSON(value));
                }
            }
        });
    }
    else { // otherwise just set the value
        result = messages;
    }
    return result;
}
exports.createStructuredJSON = createStructuredJSON;
function __structureObject(keys, val) {
    var obj = {};
    if (keys.length !== 1) {
        var currentKey = keys.shift(); // let's take the head and start recursion
        if (currentKey) {
            obj[currentKey] = __structureObject(keys, val);
        }
    }
    else { // we already have the tail
        obj[keys[0]] = val; // so let's store the value
    }
    return obj;
}
exports.__structureObject = __structureObject;
//# sourceMappingURL=structuredJSON.js.map