/// <reference types="react" />
import { Map } from 'immutable';
import Connector from './Connector';
import { DefaultFormatOptions, FormatOptions, GivenDate } from './format';
import { AppStore, InterpolationDictionary, Messages, MsgOptions, TranslationResult, TranslatorOptions } from './types';
export declare type Msg = (key: string | string[], options?: MsgOptions) => TranslationResult;
export declare type MsgClickHanlder = (key: string | string[], element: React.Component<any, any>) => void;
export declare type Key = (key: string | string[], options?: MsgOptions) => string;
export interface ResolveResult {
    result: TranslationResult;
    usedKey: string;
}
export declare type Resolve = (key: string | string[], options?: MsgOptions) => ResolveResult;
export declare type FormatDate = (givenDate: GivenDate, customFormat?: string) => string;
export declare type FormatNumber = (givenNumber: number, options?: FormatOptions) => string;
export declare type StateOptions = Map<string, string | number>;
export declare type LookupResult = TranslationResult | Messages;
export declare class Translator {
    messages: Map<string, string | number | boolean | object | Map<string, TranslationResult> | undefined>;
    locale: string;
    fallbackLocale: string;
    store: AppStore | null;
    connector: Connector | undefined;
    listeners: MsgClickHanlder[];
    constructor(options: TranslatorOptions | AppStore, connector?: Connector);
    onMsgClick: MsgClickHanlder;
    subscribeMsgClick(listener: MsgClickHanlder): () => void;
    key: Key;
    msg: Msg;
    resolve: Resolve;
    formatDate: FormatDate;
    formatNumber: FormatNumber;
    formatCurrency: FormatNumber;
    formatPercentage: FormatNumber;
    __rememberTranslation(keyPath: string | string[], message: TranslationResult): TranslationResult;
    __resolveScope(key: string, options: MsgOptions): string;
    __getPath(key: string | string[], options: MsgOptions): string[];
    __getUsedKeyForKeys(key: string[], locale: string, options: MsgOptions): string[] | false;
    __getResultForKeys(key: string[], locale: string, options: MsgOptions): string | number | boolean | object | null | undefined;
    __getOptions(type: string, key?: string, overrideOptions?: FormatOptions): DefaultFormatOptions;
    __findTranslation(keys: string[]): LookupResult;
    __findTranslationForLocale(locale: string, keys: string[]): LookupResult;
    __locale(): string;
    __fallbackLocale(): string;
    __messages(): Messages;
    __hasInterpolation(msg: string): boolean;
    __interpolate(msg: string, dictionary: InterpolationDictionary): string;
}
