"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var immutable_1 = require("immutable");
var defaultFormats_1 = require("./defaultFormats");
var format_1 = require("./format");
var structuredJSON_1 = require("./structuredJSON");
var INTERPOLATION_REGEXP = /%{([\w0-9]+)}/g;
function isAppStore(x) {
    return (x && typeof x.getState === 'function');
}
var Translator = /** @class */ (function () {
    function Translator(options, connector) {
        var _this = this;
        this.messages = immutable_1.Map();
        this.locale = 'en';
        this.fallbackLocale = '';
        this.store = null;
        this.listeners = [];
        this.onMsgClick = function (key, element) {
            _this.listeners.forEach(function (listener) { return listener(key, element); });
        };
        // tslint:disable-next-line:typedef
        this.key = function (key, givenOptions) { return _this.resolve(key, givenOptions).usedKey; };
        // tslint:disable-next-line:typedef
        this.msg = function (key, givenOptions) { return _this.resolve(key, givenOptions).result; };
        this.resolve = function (key, givenOptions) {
            var options = givenOptions || {};
            var defaultTextFromKey = Array.isArray(key) ? key[0] : key;
            if (Array.isArray(key)) {
                var foundMatch = _this.__getResultForKeys(key, _this.__locale(), options) ||
                    _this.__getResultForKeys(key, _this.__fallbackLocale(), options);
                if (foundMatch && typeof foundMatch !== 'object') {
                    var usedKey_1 = (_this.__getUsedKeyForKeys(key, _this.__locale(), options) || _this.__getUsedKeyForKeys(key, _this.__fallbackLocale(), options) || key).join('.');
                    _this.__rememberTranslation(usedKey_1, foundMatch);
                    return { result: foundMatch, usedKey: usedKey_1 };
                }
            }
            var result = _this.__findTranslation(_this.__getPath(key, options));
            var keyPaths = _this.__getPath(key, options);
            var defaultText = options.disableDefault ? undefined : defaultTextFromKey;
            var returnText = result || defaultText;
            var usedKey = (returnText === defaultTextFromKey && Array.isArray(key) ? _this.__resolveScope(key[0], options) : keyPaths.join('.'));
            _this.__rememberTranslation(usedKey, returnText);
            if (immutable_1.Map.isMap(result)) {
                return { result: result.toJS(), usedKey: usedKey };
            }
            else {
                if (typeof returnText === 'string' && _this.__hasInterpolation(returnText)) {
                    return { result: _this.__interpolate(returnText, options), usedKey: usedKey };
                }
                else {
                    return { result: returnText, usedKey: usedKey };
                }
            }
        };
        this.formatDate = function (givenDate, customFormat) {
            var keywordFormat = customFormat && _this.__findTranslation(['formats', 'date', customFormat, 'format']);
            var defaultFormat = _this.__findTranslation(['formats'].concat(['date', 'default', 'format']));
            var format = (keywordFormat || customFormat || defaultFormat || defaultFormats_1.default.formats.date.default.format);
            return format_1.formatDate(givenDate, _this.locale, format);
        };
        this.formatNumber = function (givenNumber, options) {
            if (typeof options === 'string') {
                return format_1.formatNumber(givenNumber, _this.__getOptions('number', options, {}));
            }
            else {
                return format_1.formatNumber(givenNumber, _this.__getOptions('number', undefined, options));
            }
        };
        this.formatCurrency = function (givenNumber, options) {
            var defaultFormat = _this.__getOptions('number', 'currency', options);
            return format_1.formatNumber(givenNumber, defaultFormat);
        };
        this.formatPercentage = function (givenNumber, options) {
            var defaultFormat = _this.__getOptions('number', 'percentage', options);
            return format_1.formatNumber(givenNumber, defaultFormat);
        };
        if (isAppStore(options)) {
            this.store = options;
        }
        else {
            this.messages = structuredJSON_1.createStructuredJSON(options.messages) || immutable_1.fromJS({ en: {} });
            this.locale = options.locale;
            this.fallbackLocale = options.fallbackLocale || this.fallbackLocale;
        }
        this.connector = connector;
    }
    Translator.prototype.subscribeMsgClick = function (listener) {
        var _this = this;
        this.listeners.push(listener);
        var unsubscribe = function () {
            _this.listeners.splice(_this.listeners.indexOf(listener), 1);
        };
        return unsubscribe;
    };
    Translator.prototype.__rememberTranslation = function (keyPath, message) {
        if (!this.connector) {
            return message;
        }
        if (message) {
            this.connector.rememberUsedTranslation(this.__locale(), keyPath, message);
        }
        return message;
    };
    Translator.prototype.__resolveScope = function (key, options) {
        return options.scope ? options.scope.split('.').concat(key).join('.') : key;
    };
    Translator.prototype.__getPath = function (key, options) {
        var splittedKey = [].concat(key).join('.').split('.');
        return options.scope ? options.scope.split('.').concat(splittedKey) : splittedKey;
    };
    Translator.prototype.__getUsedKeyForKeys = function (key, locale, options) {
        var _this = this;
        return key.reduce(function (acc, subKey) { return acc || (!!_this.__findTranslationForLocale(locale, _this.__getPath(subKey, options)) && _this.__getPath(subKey, options)); }, false);
    };
    Translator.prototype.__getResultForKeys = function (key, locale, options) {
        var _this = this;
        return key.reduce(function (acc, subKey) { return acc || _this.__findTranslationForLocale(locale, _this.__getPath(subKey, options)); }, null);
    };
    // tslint:disable-next-line:typedef
    Translator.prototype.__getOptions = function (type, key, overrideOptions) {
        if (overrideOptions === void 0) { overrideOptions = {}; }
        var defaultTypeOptions = this.__findTranslation(['formats'].concat(type, 'default'));
        var keyOptions = key && this.__findTranslation(['formats'].concat(type, key));
        var result = __assign({}, format_1.defaultOptions, defaultFormats_1.default.formats[type].default, (key && defaultFormats_1.default.formats[type][key]), (defaultTypeOptions && defaultTypeOptions.toJS()), (keyOptions && keyOptions.toJS()), overrideOptions);
        return result;
    };
    Translator.prototype.__findTranslation = function (keys) {
        return this.__findTranslationForLocale(this.__locale(), keys) ||
            this.__findTranslationForLocale(this.__fallbackLocale(), keys);
    };
    Translator.prototype.__findTranslationForLocale = function (locale, keys) {
        return this.__messages().getIn([locale].concat(keys));
    };
    Translator.prototype.__locale = function () {
        if (this.store) {
            return this.store.getState().translate.locale;
        }
        else {
            return this.locale;
        }
    };
    Translator.prototype.__fallbackLocale = function () {
        if (this.store) {
            return this.store.getState().translate.fallbackLocale || this.locale;
        }
        else {
            return this.fallbackLocale || this.locale;
        }
    };
    Translator.prototype.__messages = function () {
        if (this.store) {
            return this.store.getState().translate.messages;
        }
        return this.messages || immutable_1.fromJS({});
    };
    Translator.prototype.__hasInterpolation = function (msg) {
        return INTERPOLATION_REGEXP.test(msg);
    };
    Translator.prototype.__interpolate = function (msg, dictionary) {
        return msg.replace(INTERPOLATION_REGEXP, function (val, match) {
            return "" + dictionary[match];
        });
    };
    return Translator;
}());
exports.Translator = Translator;
//# sourceMappingURL=translator.js.map